==============================
Redis cache backend for Django
==============================

Full featured redis cache backend for Django.

.. image:: https://jazzband.co/static/img/badge.svg
    :target: https://jazzband.co/
    :alt: Jazzband

.. image:: https://travis-ci.org/jazzband/django-redis.svg?branch=master
    :target: https://travis-ci.org/jazzband/django-redis

.. image:: https://img.shields.io/pypi/v/django-redis.svg?style=flat
    :target: https://pypi.org/project/django-redis/

This is a `Jazzband <https://jazzband.co>`_ project. By contributing you agree
to abide by the `Contributor Code of Conduct
<https://jazzband.co/about/conduct>`_ and follow the `guidelines
<https://jazzband.co/about/guidelines>`_.

django-redis is a full featured Redis cache and session backend for Django.

Documentation
-------------

http://jazzband.github.io/django-redis/latest/

How to install
--------------

Use ``pip`` to install:

.. code-block:: console

    $ python -m pip install django-redis
